### Alignment Checking

Alignment Checking will be done by the Church Network Delegates. These are people who are chosen by the church leaders in the language community. These people are first-language speakers of the target language, are knowledgeable about the Bible, and are persons whose opinions are respected by the church leaders. If possible, they should be people who are trained in biblical languages, biblical content, and translation principles. When these people affirm the translation, the church leaders will approve of the distribution and use of the translation among the people who know and respect them.

If these people do not exist in the language community, then the translation team may want to collaborate with Quality Checkers from outside the language community in order to do Alignment Checking. In this case, it may be necessary to prepare a [backtranslation](../vol2-backtranslation/01.md).

Those who do Alignment Checking should be other than the people who did the previous [Accuracy Checking](../accuracy-check/01.md). Since Alignment Checking is also a form of accuracy checking, the translation will receive the maximum benefit if different people do each of these checks.

The purpose of Alignment Checking is to ensure that the translation accurately communicates the message of the original language texts and reflects the sound doctrine of the global Church throughout history and throughout the world. After Alignment Checking, the leaders of the churches that speak the target language can affirm that the translation is trustworthy for their people.

It is best if the leaders from every Church network in the language community can appoint or approve some of the people who will do the Alignment Checking. In that way, all of the church leaders will be able to affirm that the translation is trustworthy and useful for all of the churches of the community.

The tool that we recommend for Alignment Checking is the Alignment Tool in translationCore®. To learn how to use this tool, continue reading below.

If you are a Quality Checker (QC) and are using Alignment Checking as part of your checking process, go to [Steps for Quality Checkers](../vol2-steps/01.md) to see the rest of the QC checking process.

#### In order to use the Alignment Tool to do Alignment Checking:

1. Load the translation of the Bible book that you want to check into translationCore®.
1. Choose the Word Alignment tool.
1. Navigate through the verses using the menu of chapters and verses on the left side.
    * When you click on a verse in the menu list to open it, the words of that verse appear in a vertical list, ordered from top to bottom, just to the right of the list of chapters and verses. Each word is in a separate box.
    * The words of the original language (Greek, Hebrew, or Aramaic) text for that verse are also in separate boxes in a field to the right of the target language word list. There is a space under each of the original language word boxes outlined with a dotted line.
1. In each verse, drag the target language words in the word bank onto the space below the original language words that express that same meaning.
    * To drag a word, click and hold down the button as you move each word box of the target language into the space under the word box of the source (original) text that the word corresponds to. Drop the target language word by releasing the mouse button.
    * When the target language word is over a word box of the original, the dotted outline will turn blue to let you know that the word will drop there. If you make a mistake or decide that the target word belongs somewhere else, simply drag it again to where it belongs. Target language words can also be dragged back to the list.
    * If there are repeated words in a verse, make sure to drag only the words that correspond to that part of the meaning of the original language verse. Then drag the repeated words to the place in the original verse where that meaning is repeated.
    * When the same target language word occurs more than once in a verse, each instance of the word will have a small superscript number after it. This number will help you to align each repeated target word to the correct original word in the correct order.
    * You may need to combine original language words and/or target language words in order to make groups of words that have equivalent meanings. The goal of aligning is to match the smallest group of target language words to the smallest group of original language words that have the same meaning.

When you have finished this process for a verse, it should be easy to see if there are words left over in either the target word bank or the original language pane.

* If there are target language words left over, this may mean that there is something that has been added that does not belong in the translation. If the left-over words are expressing implied information, then they are not necessarily extra, but could be aligned to the word or words that they are explaining.
* If there are original language words left over, this may mean that the translation needs to include a translation of these words.
* If you determine that the translation has words that it should not have or is missing a translation of some words of the original text, then someone will need to edit the translation. You can either make a comment to tell someone else what to change in the translation, or you can edit the translation directly in the Alignment Tool, depending on your role in the Translation Team.

#### Alignment Philosophy

The Alignment Tool supports one-to-one, one-to-many, many-to-one, and many-to-many alignments. That means that one or more target langage words can be aligned to one or more original language words, as necessary, to get the most accurate alignment of the **meaning** conveyed by the two languages. Do not be concerned if the target language uses more or fewer words than the original language to express something. Because languages are different, that is to be expected. With the Alignment Tool, you are really aligning **meaning**, not just words. It is most important that the target translation express the **meaning** of the original Bible well, no matter how many words it takes to do that. By aligning the target language words that express the original language **meaning**, we can see if all of the original language **meaning** is there in the translation.

Because each target language will have different requirements for sentence structure and the amount of explicit information that must be provided, there will often be some target language words that do not have an exact match to any original language words. If these words are there to give information that the sentence needs in order to make sense, or to provide some implicit information that is necessary for understanding the sentence, then the target words that are provided should be aligned with the original language word that implies them, or that they help to explain.

#### Merge and Unmerge Instructions

* To align multiple target language words to a single original language word, simply drag and drop the target language words onto the box below the desired original language word.
* When it is desired to align target language word(s) to a combination of original language words, first drag one of the combination original language words into the same box as the other original language word. Multiple original language words can be merged together in this fashion.
* To unmerge previously merged original language words, drag the rightmost original language word slightly to the right. A small new alignment box will appear, and the unmerged original language word can be dropped into that box. (The leftmost original language word can also be unmerged by dragging and dropping it into the original language word box immediately to its left.)
* Any target language words that were aligned with that original language word then return to the word list.
* The original language words should remain in the proper order. If the merge contains 3 or more original language words, unmerge the rightmost original language word first. Un-merging the center word(s) first may result in the original language words becoming out of order. When that happens, unmerge the remaining words in that box to properly return the original language words to their original order.

#### After Aligning

If you are a Quality Checker, after you have finished aligning a Bible book and making questions and comments about the translation, it is time to either send the questions to the translation team or plan to meet together with the translation team and discuss them. For the steps to complete this process, return to where you left off on the [Steps for Quality Checkers](../vol2-steps/01.md) page.

To learn more about the kinds of things that need to be checked, go to [Types of Things to Check](../vol2-things-to-check/01.md).
