## Conditional Relationships

Conditional connectors connect two clauses to indicate that one of them will happen when the other one happens. In English, the most common way to connect conditional clauses is with the words, “if … then.” Often, however, the word “then” is not stated.

### Contrary-to-Fact Conditions

#### Description

A Contrary-to-Fact Condition is a condition that sounds hypothetical, but the speaker is already certain that it is NOT true.

#### Reason This Is a Translation Issue

Usually there are no special words that indicate a Contrary-to-Fact Condition. The writer assumes that the reader knows that it is NOT a true condition. For this reason it often requires knowledge of implied information to know that it is not true. If this kind of condition is difficult for translators to communicate, they may want to consider using the same strategies that they used for [Rhetorical Questions](../figs-rquestion/01.md) or [Implied Information](../figs-explicit/01.md).

#### Examples From OBS and the Bible

> But **if Baal is God**, worship him! (Story 19 Frame 6 OBS)

> Elijah came near to all the people and said, “How long will you keep changing your mind? If Yahweh is God, follow him. But **if Baal is God**, then follow him.” Yet the people did not answer him a word. (1 Kings 18:21 ULT)

Baal is not God. Elijah is not suggesting that Baal might be God, and he does not want the people to follow Baal. But Elijah used a conditional statement to show them that what they were doing was wrong. In the example above, we see two conditions that have the same construction. The first one, “If Yahweh is God,” is a Factual Condition because Elijah is certain that it is true. The second one, “if Baal is God,” is a Contrary-to-Fact Condition because Elijah is certain that it is not true. You will need to consider if people would say both of these in the same way in your language or if they would say them in different ways.

> But his wife replied to him, “**If Yahweh had desired to kill us**, he would not have taken from our hand the whole burnt offering and the offering. He would not have shown us all these things, and at this time would he have not allowed us to hear about this.” (Judges 13:23 ULT)

Manoah’s wife thinks that the second part of her conditional statement is not true, therefore the first part is also not true. God received their burnt offering; therefore, He does not want to kill them.
>

> “**If only we had died** by Yahweh’s hand in the land of Egypt, sitting by a pot of meat and eating bread to the full.” (Exodus 16b:3 ULT)

Of course the people speaking here did not die in Egypt, and so this is a Contrary-to-Fact condition that is used to express a wish.

> “Woe to you, Chorazin! Woe to you, Bethsaida! **If the mighty deeds had been done** in Tyre and Sidon which were done in you, **they would have repented** long ago in sackcloth and ashes.” (Matthew 11:21 ULT)

The English reader knows that these last two examples are Contrary-to-Fact conditions because of the past-tense verbs used in the first part (they are not things that might happen). The last example also has a second part that uses “would have.” These words also signal something that did not happen.

#### Translation Strategies

If Contrary-to-Fact conditions are clear in your language, then use them as they are.

(1) If the condition leads the reader to think that the speaker believes something that is false, then restate the condition as something that others believe.<br>
(2) If the condition leads the reader to think that the speaker is suggesting that the first part is true, then restate it as a statement that it is not true.<br>
(3) If the condition is expressing something that did not happen but the speaker wanted it to happen, restate it as a wish.<br>
(4) If the condition is expressing something that did not happen, restate it as a negative statement.<br>
(5) Often Factual and Contrary-to-Fact conditions are used to make reasoned arguments for a change in behavior. If translators are struggling to know the best way to translate them, it could be helpful to discuss how this is done in their language community. If someone is trying to convince people to change their behavior, how do they do that? It may be possible to adapt similar strategies when translating these conditions.

#### Examples of Translation Strategies Applied

(1) If the condition leads the reader to think that the speaker believes something that is false, then restate the condition as something that others believe.

> But **if Baal is God**, worship him! (Story 19 Frame 6 OBS)

> > If you believe that Baal is God, then worship him!

(2) If the condition leads the reader to think that the speaker is suggesting that the first part is true, then restate it as a statement that it is not true.

> > If Baal is not God, then you should not worship him!

But his wife replied to him, “**If Yahweh had desired to kill us**, he would not have taken from our hand the whole burnt offering and the offering. He would not have shown us all these things, and at this time would he have not allowed us to hear about this.” (Judges 13:23 ULT)

> > “**Yahweh does not want to kill us**, or he would not have received the burnt offering and the offering we gave him.”

(3) If the condition is expressing something that did not happen but the speaker wanted it to happen, restate it as a wish.

> “**If only we had died** by Yahweh’s hand in the land of Egypt, sitting by a pot of meat and eating bread to the full.” (Exodus 16b:3 ULT)
> > “**I wish we had died** by Yahweh’s hand in the land of Egypt…”

(4) If the condition is expressing something that did not happen, restate it as a negative statement.

> “Woe to you, Chorazin! Woe to you, Bethsaida! **If the mighty deeds had been done** in Tyre and Sidon which were done in you, **they would have repented** long ago in sackcloth and ashes.” (Matthew 11:21 ULT)

> > “Woe to you, Chorazin! Woe to you, Bethsaida! The mighty deeds which were done in you **were not done** in Tyre and Sidon. But **if they had been done there, those people would have repented** long ago in sackcloth and ashes.”

(5) Often Factual and Contrary-to-Fact Conditions are used to make reasoned arguments for a change in behavior. If translators are struggling to know the best way to translate them, it could be helpful to discuss how this is done in their language community. If someone is trying to convince people to change their behavior, how do they do that? It may be possible to adapt similar strategies when translating these conditions.

> But **if Baal is God**, worship him! (Story 19 Frame 6 OBS)

> > Is Baal the one who is truly God? Should you worship him?

> “Woe to you, Chorazin! Woe to you, Bethsaida! **If the mighty deeds had been done** in Tyre and Sidon which were done in you, **they would have repented** long ago in sackcloth and ashes.” (Matthew 11:21 ULT)

> > “Woe to you, Chorazin! Woe to you, Bethsaida! You think that you are better than Tyre and Sidon, but you are not! **They would have repented** long ago in sackcloth and ashes at seeing the mighty deeds that you have seen! **You should be like them**!”
